@@ -1,12 +1,12 @@
 patterns = ['permission denied',
-            'EACCES',
-            'pkg: Insufficient privileges',
+            'eacces',
+            'pkg: insufficient privileges',
             'you cannot perform this operation unless you are root',
             'non-root users cannot',
-            'Operation not permitted',
+            'operation not permitted',
             'root privilege',
-            'This command has to be run under the root user.',
-            'This operation requires root.',
+            'this command has to be run under the root user.',
+            'this operation requires root.',
             'requested operation requires superuser privilege',
             'must be run as root',
             'must run as root',
@@ -14,10 +14,13 @@ patterns = ['permission denied',
             'must be root',
             'need to be root',
             'need root',
+            'needs to be run as root',
             'only root can ',
-            'You don\'t have access to the history DB.',
+            'you don\'t have access to the history db.',
             'authentication is required',
-            'eDSPermissionError']
+            'edspermissionerror',
+            'you don\'t have write permissions',
+            'use `sudo`']
 
 
 def match(command):
@@ -25,8 +28,8 @@ def match(command):
         return False
 
     for pattern in patterns:
-        if pattern.lower() in command.stderr.lower()\
-                or pattern.lower() in command.stdout.lower():
+        if pattern in command.stderr.lower()\
+                or pattern in command.stdout.lower():
             return True
     return False
 
