@@ -4,6 +4,7 @@ import os
 import sys
 import six
 from .. import logs
+from ..conf import settings
 from ..utils import DEVNULL, memoize, cache
 from .generic import Generic
 
@@ -18,17 +19,21 @@ class Fish(Generic):
         return default
 
     def app_alias(self, fuck):
+        if settings.alter_history:
+            alter_history = ('    builtin history delete --exact'
+                             ' --case-sensitive -- $fucked_up_command\n'
+                             '    builtin history merge ^ /dev/null\n')
+        else:
+            alter_history = ''
         # It is VERY important to have the variables declared WITHIN the alias
         return ('function {0} -d "Correct your previous console command"\n'
                 '  set -l fucked_up_command $history[1]\n'
                 '  env TF_ALIAS={0} PYTHONIOENCODING=utf-8'
                 ' thefuck $fucked_up_command | read -l unfucked_command\n'
                 '  if [ "$unfucked_command" != "" ]\n'
-                '    eval $unfucked_command\n'
-                '    history --delete $fucked_up_command\n'
-                '    history --merge ^ /dev/null\n'
+                '    eval $unfucked_command\n{1}'
                 '  end\n'
-                'end').format(fuck)
+                'end').format(fuck, alter_history)
 
     @memoize
     @cache('.config/fish/config.fish', '.config/fish/functions')
@@ -46,10 +51,6 @@ class Fish(Generic):
         else:
             return command_script
 
-    def from_shell(self, command_script):
-        """Prepares command before running in app."""
-        return self._expand_aliases(command_script)
-
     def _get_history_file_name(self):
         return os.path.expanduser('~/.config/fish/fish_history')
 
