@@ -9,7 +9,6 @@ from .shells import shell
 from .conf import settings
 from .const import DEFAULT_PRIORITY, ALL_ENABLED
 from .exceptions import EmptyCommand
-from .utils import compatibility_call
 
 
 class Command(object):
@@ -34,8 +33,9 @@ class Command(object):
                 self._script_parts = shell.split_command(self.script)
             except Exception:
                 logs.debug(u"Can't split command script {} because:\n {}".format(
-                        self, sys.exc_info()))
-                self._script_parts = None
+                    self, sys.exc_info()))
+                self._script_parts = []
+
         return self._script_parts
 
     def __eq__(self, other):
@@ -47,7 +47,7 @@ class Command(object):
 
     def __repr__(self):
         return u'Command(script={}, stdout={}, stderr={})'.format(
-                self.script, self.stdout, self.stderr)
+            self.script, self.stdout, self.stderr)
 
     def update(self, **kwargs):
         """Returns new command with replaced fields.
@@ -61,7 +61,7 @@ class Command(object):
         return Command(**kwargs)
 
     @staticmethod
-    def _wait_output(popen):
+    def _wait_output(popen, is_slow):
         """Returns `True` if we can get output of the command in the
         `settings.wait_command` time.
 
@@ -73,7 +73,8 @@ class Command(object):
         """
         proc = Process(popen.pid)
         try:
-            proc.wait(settings.wait_command)
+            proc.wait(settings.wait_slow_command if is_slow
+                      else settings.wait_command)
             return True
         except TimeoutExpired:
             for child in proc.children(recursive=True):
@@ -113,9 +114,12 @@ class Command(object):
         env = dict(os.environ)
         env.update(settings.env)
 
-        with logs.debug_time(u'Call: {}; with env: {};'.format(script, env)):
-            result = Popen(script, shell=True, stdin=PIPE, stdout=PIPE, stderr=PIPE, env=env)
-            if cls._wait_output(result):
+        is_slow = script.split(' ')[0] in settings.slow_commands
+        with logs.debug_time(u'Call: {}; with env: {}; is slow: '.format(
+                script, env, is_slow)):
+            result = Popen(script, shell=True, stdin=PIPE,
+                           stdout=PIPE, stderr=PIPE, env=env)
+            if cls._wait_output(result, is_slow):
                 stdout = result.stdout.read().decode('utf-8')
                 stderr = result.stderr.read().decode('utf-8')
 
@@ -168,9 +172,9 @@ class Rule(object):
         return 'Rule(name={}, match={}, get_new_command={}, ' \
                'enabled_by_default={}, side_effect={}, ' \
                'priority={}, requires_output)'.format(
-                self.name, self.match, self.get_new_command,
-                self.enabled_by_default, self.side_effect,
-                self.priority, self.requires_output)
+            self.name, self.match, self.get_new_command,
+            self.enabled_by_default, self.side_effect,
+            self.priority, self.requires_output)
 
     @classmethod
     def from_path(cls, path):
@@ -221,7 +225,7 @@ class Rule(object):
 
         try:
             with logs.debug_time(u'Trying rule: {};'.format(self.name)):
-                if compatibility_call(self.match, command):
+                if self.match(command):
                     return True
         except Exception:
             logs.rule_failed(self, sys.exc_info())
@@ -233,7 +237,7 @@ class Rule(object):
         :rtype: Iterable[CorrectedCommand]
 
         """
-        new_commands = compatibility_call(self.get_new_command, command)
+        new_commands = self.get_new_command(command)
         if not isinstance(new_commands, list):
             new_commands = (new_commands,)
         for n, new_command in enumerate(new_commands):
@@ -270,7 +274,7 @@ class CorrectedCommand(object):
 
     def __repr__(self):
         return u'CorrectedCommand(script={}, side_effect={}, priority={})'.format(
-                self.script, self.side_effect, self.priority)
+            self.script, self.side_effect, self.priority)
 
     def run(self, old_cmd):
         """Runs command from rule for passed command.
@@ -279,7 +283,7 @@ class CorrectedCommand(object):
 
         """
         if self.side_effect:
-            compatibility_call(self.side_effect, old_cmd, self.script)
+            self.side_effect(old_cmd, self.script)
         if settings.alter_history:
             shell.put_to_history(self.script)
         # This depends on correct setting of PYTHONIOENCODING by the alias:
