@@ -4,14 +4,13 @@ import pkg_resources
 import re
 import shelve
 import six
-from .conf import settings
 from contextlib import closing
 from decorator import decorator
 from difflib import get_close_matches
 from functools import wraps
-from inspect import getargspec
-from pathlib import Path
 from warnings import warn
+from .conf import settings
+from .system import Path
 
 DEVNULL = open(os.devnull, 'w')
 
@@ -110,7 +109,7 @@ def get_all_executables():
     tf_entry_points = get_installation_info().get_entry_map()\
                                              .get('console_scripts', {})\
                                              .keys()
-    bins = [exe.name
+    bins = [exe.name.decode('utf8') if six.PY2 else exe.name
             for path in os.environ.get('PATH', '').split(':')
             for exe in _safe(lambda: list(Path(path).iterdir()), [])
             if not _safe(exe.is_dir, True)
@@ -160,7 +159,7 @@ def is_app(command, *app_names, **kwargs):
     if kwargs:
         raise TypeError("got an unexpected keyword argument '{}'".format(kwargs.keys()))
 
-    if command.script_parts is not None and len(command.script_parts) > at_least:
+    if len(command.script_parts) > at_least:
         return command.script_parts[0] in app_names
 
     return False
@@ -242,27 +241,6 @@ def cache(*depends_on):
 cache.disabled = False
 
 
-def compatibility_call(fn, *args):
-    """Special call for compatibility with user-defined old-style rules
-    with `settings` param.
-
-    """
-    fn_args_count = len(getargspec(fn).args)
-    if fn.__name__ in ('match', 'get_new_command') and fn_args_count == 2:
-        warn("Two arguments `{}` from rule `{}` is deprecated, please "
-             "remove `settings` argument and use "
-             "`from thefuck.conf import settings` instead."
-             .format(fn.__name__, fn.__module__))
-        args += (settings,)
-    if fn.__name__ == 'side_effect' and fn_args_count == 3:
-        warn("Three arguments `side_effect` from rule `{}` is deprecated, "
-             "please remove `settings` argument and use `from thefuck.conf "
-             "import settings` instead."
-             .format(fn.__name__, fn.__module__))
-        args += (settings,)
-    return fn(*args)
-
-
 def get_installation_info():
     return pkg_resources.require('thefuck')[0]
 
